@@ -9,18 +9,18 @@
 #include <time.h>
 
 
-#ifndef  _MSC_VER
+#if !defined(_MSC_VER) || (_MSC_VER >= 1800)
     #include <stdint.h>
     #include <inttypes.h>
 #else
     typedef signed char        int8_t;
     typedef unsigned char      uint8_t;
-	typedef unsigned short     uint16_t;
-	typedef short              int16_t;
+    typedef unsigned short     uint16_t;
+    typedef short              int16_t;
     typedef unsigned int       uint32_t;
-	typedef int                int32_t;
-	typedef unsigned long long uint64_t;
-	typedef long long          int64_t;
+    typedef int                int32_t;
+    typedef unsigned long long uint64_t;
+    typedef long long          int64_t;
 #endif
 
 #ifndef _WIN32
@@ -47,3 +47,8 @@
 
 
 #endif
+
+#if defined (__SVR4) && defined (__sun)
+    #define LITTLE_ENDIAN 1234
+    #define BYTE_ORDER LITTLE_ENDIAN
+#endif
